@@ -23,7 +23,9 @@
 #include <QApplication>
 #endif
 
+#include <QCommandLineParser>
 #include <QIcon>
+#include <QTimer>
 #include <QtPlugin>
 
 #if HAVE_OSM_PBF_SUPPORT
@@ -68,12 +70,22 @@ int main(int argc, char **argv)
     QGuiApplication::setApplicationDisplayName(i18n("KDE OSM Indoor Map"));
     QGuiApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("go-home")));
 
+    QCommandLineParser parser;
+    QCommandLineOption selfTestOpt(QStringLiteral("self-test"), QStringLiteral("internal, for automated testing"));
+    parser.addOption(selfTestOpt);
+    parser.process(app);
+
     QQmlApplicationEngine engine;
     engine.setNetworkAccessManagerFactory(new NetworkAccessManagerFactory());
     auto l10nContext = new KLocalizedContext(&engine);
     l10nContext->setTranslationDomain(QStringLiteral(TRANSLATION_DOMAIN));
     engine.rootContext()->setContextObject(l10nContext);
 
-    engine.load(QStringLiteral("qrc:/indoormap.qml"));
+    engine.loadFromModule("org.kde.kosmindoormap.app", "Main");
+
+    if (parser.isSet(selfTestOpt)) {
+        QTimer::singleShot(std::chrono::milliseconds(250), &app, &QCoreApplication::quit);
+    }
+
     return app.exec();
 }
