@@ -11,6 +11,9 @@
 
 #include <osm/element.h>
 
+#include <wikidata/entities.h>
+#include <wikidata/wikidataquerymanager.h>
+
 #include <QAbstractListModel>
 
 namespace KOSMIndoorMap {
@@ -24,6 +27,7 @@ class OSMElementInformationModel : public QAbstractListModel
     Q_PROPERTY(KOSMIndoorMap::OSMElement element READ element WRITE setElement NOTIFY elementChanged)
     Q_PROPERTY(QString name READ name NOTIFY elementChanged)
     Q_PROPERTY(QString category READ category NOTIFY elementChanged)
+    Q_PROPERTY(bool allowOnlineContent MEMBER m_allowOnlineContent NOTIFY allowOnlineContentChanged)
     Q_PROPERTY(bool debug MEMBER m_debug)
 
 public:
@@ -57,10 +61,13 @@ public:
         NoKey,
         Name,
         Category,
+        Image,
+        Logo,
         OldName,
         Description,
         Routes,
         Cuisine,
+        VendingMachineOffer,
         Diet,
         Takeaway,
         Socket,
@@ -105,43 +112,48 @@ public:
         Link,
         PostalAddress,
         OpeningHoursType,
+        ImageType,
     };
     Q_ENUM(Type)
 
-    OSMElement element() const;
+    [[nodiscard]] OSMElement element() const;
     void setElement(const OSMElement &element);
     Q_INVOKABLE void clear();
 
-    QString name() const;
-    QString category() const;
+    [[nodiscard]] QString name() const;
+    [[nodiscard]] QString category() const;
 
-    int rowCount(const QModelIndex &parent = {}) const override;
-    QVariant data(const QModelIndex &index, int role) const override;
-    QHash<int, QByteArray> roleNames() const override;
+    [[nodiscard]] int rowCount(const QModelIndex &parent = {}) const override;
+    [[nodiscard]] QVariant data(const QModelIndex &index, int role) const override;
+    [[nodiscard]] QHash<int, QByteArray> roleNames() const override;
 
 Q_SIGNALS:
     void elementChanged();
+    void allowOnlineContentChanged();
 
 private:
     struct Info;
 
     void reload();
+    /** Process online content, filter out things we don't want, etc. */
+    void resolveOnlineContent();
     /** Resolve elements who's group depends on context. */
     void resolveCategories();
     /** Make sure we have at least one naming element. */
     void resolveHeaders();
-    bool promoteMainCategory(KeyCategory cat);
-    QString categoryLabel(KeyCategory cat) const;
-    QString debugTagKey(int row) const;
-    QString debugTagValue(int row) const;
-    QString keyName(Key key) const;
-    QVariant valueForKey(Info info) const;
-    QVariant urlify(const QVariant &v, Key key) const;
-    QString paymentMethodList(Key key) const;
-    QString paymentMethodValue(Key key) const;
-    QUrl wikipediaUrl(const QByteArray &wp) const;
-    QString capacitryValue(const char *prop) const;
-    QString translatedBoolValue(const QByteArray &value) const;
+    [[nodiscard]] bool promoteMainCategory(KeyCategory cat);
+    [[nodiscard]] QString categoryLabel(KeyCategory cat) const;
+    [[nodiscard]] QString debugTagKey(int row) const;
+    [[nodiscard]] QString debugTagValue(int row) const;
+    [[nodiscard]] QUrl debugTagUrl(int row) const;
+    [[nodiscard]] QString keyName(Key key) const;
+    [[nodiscard]] QVariant valueForKey(Info info) const;
+    [[nodiscard]] QVariant urlify(const QVariant &v, Key key) const;
+    [[nodiscard]] QString paymentMethodList(Key key) const;
+    [[nodiscard]] QString paymentMethodValue(Key key) const;
+    [[nodiscard]] QUrl wikipediaUrl(const QByteArray &wp) const;
+    [[nodiscard]] QString capacitryValue(const char *prop) const;
+    [[nodiscard]] QString translatedBoolValue(const QByteArray &value) const;
 
     template <typename KeyMapEntry, std::size_t N>
     void addEntryForKey(const char *keyName, const KeyMapEntry(&map)[N]);
@@ -154,14 +166,18 @@ private:
         Key key;
         KeyCategory category;
 
-        bool operator<(Info other) const;
-        bool operator==(Info other) const;
+        [[nodiscard]] bool operator<(Info other) const;
+        [[nodiscard]] bool operator==(Info other) const;
     };
     std::vector<Info> m_infos;
     OSM::Languages m_langs;
     Key m_nameKey = NoKey;
     Key m_categoryKey = NoKey;
+    bool m_allowOnlineContent = false;
     bool m_debug = false;
+
+    Wikidata::QueryManager m_wikidataMgr;
+    QHash<Wikidata::Q, QString> m_wikidataImageMap;
 };
 
 }
